<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-plan?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// P
	'plan_description' => 'Deze plugin verbetert de weergave van de « Sitemap » in het privé gedeelte door een uitvouwbare structuur weet te geven waarin op status van artikel kan worden gefilterd.
',
	'plan_nom' => 'Sitemap in het privé gedeelte',
	'plan_slogan' => 'Verbeterde sitemap in het privé gedeelte',
];
